'use client'

import React, { useEffect, useState } from 'react';
import { RoomsType } from '../../../types/rooms';
import { useSessionTracking } from '../../../actions/hooks/useSessionTracking';
import { AccountMenu } from '../AccountMenu';
import { Loader } from '../../view/Loader';
import { RoomDetailsContent } from './RoomDetailsContent';
import { useRoomDetails } from '../../../actions/hooks/useRoomDetails';
import { AgoraClientGroup } from '../agora';
import { SupervisorReportModal } from '../../Modals/SupervisorReportModal';
import { useLocalStorage } from '../../../hooks/useLocalStorage';
import { AUTH_USER } from '../../../constants/common';

type RoomDetailsProps = {
    locale: string;
    roomId: number;
    activeType: RoomsType;
};

export const RoomDetails = ({ roomId, locale, activeType }: RoomDetailsProps) => {
    const { room, errorData, loading, fetchData, isStarted } = useRoomDetails(locale, roomId);
    const tracking = useSessionTracking(locale, roomId);
    const [isCalling, setIsCalling] = useState<boolean>(false);
    const [isOpenReport, setIsOpenReport] = useState<boolean>(false);
    const [userData] = useLocalStorage(AUTH_USER, '');
    const { id: userId = 0 } = userData ? JSON.parse(userData) : {};
    const isSupervisor = room?.supervisor && room.supervisor.id === +userId || false;

    useEffect(() => {
        if (isCalling) {
            tracking.start();
        } else {
            tracking.stop();
        }
    }, [isCalling]);

    useEffect(() => {
        if (isSupervisor && isStarted) {
            setIsOpenReport(true);
        }
    }, [isStarted]);

    const stopCalling = () => {
        setIsCalling(false);
        fetchData();
    }

    return isCalling
        ? (
            <AgoraClientGroup
                room={room}
                stopCalling={stopCalling}
            />
        ) : (
            <>
                <div className="col-xl-3 col-lg-4 d-none d-lg-block">
                    <AccountMenu locale={locale} />
                </div>
                <div className="col-xl-9 col-lg-8 ">
                    <div className="page-account__inner">
                        <Loader
                            isLoading={loading}
                            errorData={errorData}
                            refresh={fetchData}
                        >
                            <RoomDetailsContent
                                locale={locale}
                                room={room}
                                activeType={activeType}
                                startRoom={() => setIsCalling(true)}
                                refresh={fetchData}
                            />
                        </Loader>
                    </div>
                    {isSupervisor && room?.id && (
                        <SupervisorReportModal
                            open={isOpenReport}
                            handleCancel={() => setIsOpenReport(false)}
                            locale={locale}
                            refresh={fetchData}
                            roomId={room.id}
                        />
                    )}
                </div>
            </>
        );
};
